# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/common.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import amount_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2
from . import account_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/common.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n\x1corg/xrpl/rpc/v1/common.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1corg/xrpl/rpc/v1/amount.proto\x1a\x1dorg/xrpl/rpc/v1/account.proto\"\x1f\n\x0e\x42urnedNFTokens\x12\r\n\x05value\x18\x01 \x01(\r\"\x1c\n\x0b\x43\x61ncelAfter\x12\r\n\x05value\x18\x01 \x01(\r\"\x1a\n\tClearFlag\x12\r\n\x05value\x18\x01 \x01(\r\"\x1a\n\tCloseTime\x12\r\n\x05value\x18\x01 \x01(\r\"\x15\n\x04\x44\x61te\x12\r\n\x05value\x18\x01 \x01(\r\"\x1f\n\x0e\x44\x65stinationTag\x12\r\n\x05value\x18\x01 \x01(\r\"\x1b\n\nExpiration\x12\r\n\x05value\x18\x01 \x01(\r\"\x1c\n\x0b\x46inishAfter\x12\r\n\x05value\x18\x01 \x01(\r\"\x16\n\x05\x46lags\x12\r\n\x05value\x18\x01 \x01(\r\"\x1e\n\rHighQualityIn\x12\r\n\x05value\x18\x01 \x01(\r\"\x1f\n\x0eHighQualityOut\x12\r\n\x05value\x18\x01 \x01(\r\"$\n\x13\x46irstLedgerSequence\x12\r\n\x05value\x18\x01 \x01(\r\"#\n\x12LastLedgerSequence\x12\r\n\x05value\x18\x01 \x01(\r\"\x1d\n\x0cLowQualityIn\x12\r\n\x05value\x18\x01 \x01(\r\"\x1e\n\rLowQualityOut\x12\r\n\x05value\x18\x01 \x01(\r\"\x1f\n\x0eMintedNFTokens\x12\r\n\x05value\x18\x01 \x01(\r\"\x1e\n\rOfferSequence\x12\r\n\x05value\x18\x01 \x01(\r\"\x1b\n\nOwnerCount\x12\r\n\x05value\x18\x01 \x01(\r\"2\n!PreviousTransactionLedgerSequence\x12\r\n\x05value\x18\x01 \x01(\r\"\x1a\n\tQualityIn\x12\r\n\x05value\x18\x01 \x01(\r\"\x1b\n\nQualityOut\x12\r\n\x05value\x18\x01 \x01(\r\"\"\n\x11ReferenceFeeUnits\x12\r\n\x05value\x18\x01 \x01(\r\"\x1c\n\x0bReserveBase\x12\r\n\x05value\x18\x01 \x01(\r\"!\n\x10ReserveIncrement\x12\r\n\x05value\x18\x01 \x01(\r\"\x19\n\x08Sequence\x12\r\n\x05value\x18\x01 \x01(\r\"\x18\n\x07SetFlag\x12\r\n\x05value\x18\x01 \x01(\r\"\x1c\n\x0bSettleDelay\x12\r\n\x05value\x18\x01 \x01(\r\"\x1d\n\x0cSignerListID\x12\r\n\x05value\x18\x01 \x01(\r\"\x1d\n\x0cSignerQuorum\x12\r\n\x05value\x18\x01 \x01(\r\"\x1d\n\x0cSignerWeight\x12\r\n\x05value\x18\x01 \x01(\r\"\x1a\n\tSourceTag\x12\r\n\x05value\x18\x01 \x01(\r\"\x19\n\x08TickSize\x12\r\n\x05value\x18\x01 \x01(\r\"\x17\n\x06Ticket\x12\r\n\x05value\x18\x01 \x01(\r\"\x1c\n\x0bTicketCount\x12\r\n\x05value\x18\x01 \x01(\r\"\x1f\n\x0eTicketSequence\x12\r\n\x05value\x18\x01 \x01(\r\"\x1d\n\x0cNFTokenTaxon\x12\r\n\x05value\x18\x01 \x01(\r\"\x1c\n\x0bTransferFee\x12\r\n\x05value\x18\x01 \x01(\r\"\x1d\n\x0cTransferRate\x12\r\n\x05value\x18\x01 \x01(\r\"\x1c\n\x07\x42\x61seFee\x12\x11\n\x05value\x18\x01 \x01(\x04\x42\x02\x30\x01\"\x1d\n\x08\x42ookNode\x12\x11\n\x05value\x18\x01 \x01(\x04\x42\x02\x30\x01\"$\n\x0f\x44\x65stinationNode\x12\x11\n\x05value\x18\x01 \x01(\x04\x42\x02\x30\x01\"\x1d\n\x08HighNode\x12\x11\n\x05value\x18\x01 \x01(\x04\x42\x02\x30\x01\"\x1e\n\tIndexNext\x12\x11\n\x05value\x18\x01 \x01(\x04\x42\x02\x30\x01\"\"\n\rIndexPrevious\x12\x11\n\x05value\x18\x01 \x01(\x04\x42\x02\x30\x01\"\x1c\n\x07LowNode\x12\x11\n\x05value\x18\x01 \x01(\x04\x42\x02\x30\x01\"%\n\x10NFTokenOfferNode\x12\x11\n\x05value\x18\x01 \x01(\x04\x42\x02\x30\x01\"\x1e\n\tOwnerNode\x12\x11\n\x05value\x18\x01 \x01(\x04\x42\x02\x30\x01\"\x1a\n\tEmailHash\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1a\n\tNFTokenID\x12\r\n\x05value\x18\x01 \x01(\x0c\" \n\x0fTakerGetsIssuer\x12\r\n\x05value\x18\x01 \x01(\x0c\" \n\x0fTakerPaysIssuer\x12\r\n\x05value\x18\x01 \x01(\x0c\"%\n\x14\x41\x63\x63ountTransactionID\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1e\n\rBookDirectory\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x18\n\x07\x43hannel\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x18\n\x07\x43heckID\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x15\n\x04Hash\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x16\n\x05Index\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1a\n\tInvoiceID\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1c\n\x0bNextPageMin\x12\r\n\x05value\x18\x01 \x01(\x0c\" \n\x0fNFTokenBuyOffer\x12\r\n\x05value\x18\x01 \x01(\x0c\"!\n\x10NFTokenSellOffer\x12\r\n\x05value\x18\x01 \x01(\x0c\" \n\x0fPreviousPageMin\x12\r\n\x05value\x18\x01 \x01(\x0c\"&\n\x15PreviousTransactionID\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1a\n\tRootIndex\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1a\n\tCondition\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1c\n\x0b\x46ulfillment\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x19\n\x08MemoData\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1b\n\nMemoFormat\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x19\n\x08MemoType\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1b\n\nMessageKey\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1a\n\tPublicKey\x12\r\n\x05value\x18\x01 \x01(\x0c\"(\n\x17PaymentChannelSignature\x12\r\n\x05value\x18\x01 \x01(\x0c\"!\n\x10SigningPublicKey\x12\r\n\x05value\x18\x01 \x01(\x0c\"%\n\x14TransactionSignature\x12\r\n\x05value\x18\x01 \x01(\x0c\"#\n\x12ValidatorToDisable\x12\r\n\x05value\x18\x01 \x01(\x0c\"$\n\x13ValidatorToReEnable\x12\r\n\x05value\x18\x01 \x01(\x0c\"<\n\x10TakerGetsCurreny\x12(\n\x05value\x18\x01 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.Currency\"=\n\x11TakerPaysCurrency\x12(\n\x05value\x18\x01 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.Currency\"8\n\x06\x41mount\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.CurrencyAmount\"9\n\x07\x42\x61lance\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.CurrencyAmount\"B\n\x10NFTokenBrokerFee\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.CurrencyAmount\"<\n\nDeliverMin\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.CurrencyAmount\"A\n\x0f\x44\x65liveredAmount\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.CurrencyAmount\";\n\tHighLimit\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.CurrencyAmount\"=\n\x0bLimitAmount\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.CurrencyAmount\":\n\x08LowLimit\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.CurrencyAmount\"9\n\x07SendMax\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.CurrencyAmount\";\n\tTakerGets\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.CurrencyAmount\";\n\tTakerPays\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.CurrencyAmount\"9\n\x07\x41\x63\x63ount\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\";\n\tAuthorize\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\"=\n\x0b\x44\x65stination\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\"8\n\x06Issuer\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\"?\n\rNFTokenMinter\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\"7\n\x05Owner\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\"<\n\nRegularKey\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\"=\n\x0bUnauthorize\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\"\x17\n\x06\x44omain\x12\r\n\x05value\x18\x01 \x01(\t\"\x14\n\x03URI\x12\r\n\x05value\x18\x01 \x01(\t\"\\\n\x07NFToken\x12.\n\nnftoken_id\x18\x01 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.NFTokenID\x12!\n\x03uri\x18\x02 \x01(\x0b\x32\x14.org.xrpl.rpc.v1.URI\"n\n\x0bSignerEntry\x12)\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Account\x12\x34\n\rsigner_weight\x18\x02 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.SignerWeight\"\x82\x01\n\x11\x44isabledValidator\x12.\n\npublic_key\x18\x01 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.PublicKey\x12=\n\x0fledger_sequence\x18\x02 \x01(\x0b\x32$.org.xrpl.rpc.v1.FirstLedgerSequenceB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2.DESCRIPTOR,])




_BURNEDNFTOKENS = _descriptor.Descriptor(
  name='BurnedNFTokens',
  full_name='org.xrpl.rpc.v1.BurnedNFTokens',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.BurnedNFTokens.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=141,
)


_CANCELAFTER = _descriptor.Descriptor(
  name='CancelAfter',
  full_name='org.xrpl.rpc.v1.CancelAfter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.CancelAfter.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=171,
)


_CLEARFLAG = _descriptor.Descriptor(
  name='ClearFlag',
  full_name='org.xrpl.rpc.v1.ClearFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.ClearFlag.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=199,
)


_CLOSETIME = _descriptor.Descriptor(
  name='CloseTime',
  full_name='org.xrpl.rpc.v1.CloseTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.CloseTime.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=227,
)


_DATE = _descriptor.Descriptor(
  name='Date',
  full_name='org.xrpl.rpc.v1.Date',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Date.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=250,
)


_DESTINATIONTAG = _descriptor.Descriptor(
  name='DestinationTag',
  full_name='org.xrpl.rpc.v1.DestinationTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.DestinationTag.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=283,
)


_EXPIRATION = _descriptor.Descriptor(
  name='Expiration',
  full_name='org.xrpl.rpc.v1.Expiration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Expiration.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=285,
  serialized_end=312,
)


_FINISHAFTER = _descriptor.Descriptor(
  name='FinishAfter',
  full_name='org.xrpl.rpc.v1.FinishAfter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.FinishAfter.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=342,
)


_FLAGS = _descriptor.Descriptor(
  name='Flags',
  full_name='org.xrpl.rpc.v1.Flags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Flags.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=366,
)


_HIGHQUALITYIN = _descriptor.Descriptor(
  name='HighQualityIn',
  full_name='org.xrpl.rpc.v1.HighQualityIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.HighQualityIn.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=398,
)


_HIGHQUALITYOUT = _descriptor.Descriptor(
  name='HighQualityOut',
  full_name='org.xrpl.rpc.v1.HighQualityOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.HighQualityOut.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=431,
)


_FIRSTLEDGERSEQUENCE = _descriptor.Descriptor(
  name='FirstLedgerSequence',
  full_name='org.xrpl.rpc.v1.FirstLedgerSequence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.FirstLedgerSequence.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=469,
)


_LASTLEDGERSEQUENCE = _descriptor.Descriptor(
  name='LastLedgerSequence',
  full_name='org.xrpl.rpc.v1.LastLedgerSequence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.LastLedgerSequence.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=471,
  serialized_end=506,
)


_LOWQUALITYIN = _descriptor.Descriptor(
  name='LowQualityIn',
  full_name='org.xrpl.rpc.v1.LowQualityIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.LowQualityIn.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=537,
)


_LOWQUALITYOUT = _descriptor.Descriptor(
  name='LowQualityOut',
  full_name='org.xrpl.rpc.v1.LowQualityOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.LowQualityOut.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=539,
  serialized_end=569,
)


_MINTEDNFTOKENS = _descriptor.Descriptor(
  name='MintedNFTokens',
  full_name='org.xrpl.rpc.v1.MintedNFTokens',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.MintedNFTokens.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=571,
  serialized_end=602,
)


_OFFERSEQUENCE = _descriptor.Descriptor(
  name='OfferSequence',
  full_name='org.xrpl.rpc.v1.OfferSequence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.OfferSequence.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=634,
)


_OWNERCOUNT = _descriptor.Descriptor(
  name='OwnerCount',
  full_name='org.xrpl.rpc.v1.OwnerCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.OwnerCount.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=663,
)


_PREVIOUSTRANSACTIONLEDGERSEQUENCE = _descriptor.Descriptor(
  name='PreviousTransactionLedgerSequence',
  full_name='org.xrpl.rpc.v1.PreviousTransactionLedgerSequence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.PreviousTransactionLedgerSequence.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=715,
)


_QUALITYIN = _descriptor.Descriptor(
  name='QualityIn',
  full_name='org.xrpl.rpc.v1.QualityIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.QualityIn.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=743,
)


_QUALITYOUT = _descriptor.Descriptor(
  name='QualityOut',
  full_name='org.xrpl.rpc.v1.QualityOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.QualityOut.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=772,
)


_REFERENCEFEEUNITS = _descriptor.Descriptor(
  name='ReferenceFeeUnits',
  full_name='org.xrpl.rpc.v1.ReferenceFeeUnits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.ReferenceFeeUnits.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=808,
)


_RESERVEBASE = _descriptor.Descriptor(
  name='ReserveBase',
  full_name='org.xrpl.rpc.v1.ReserveBase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.ReserveBase.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=810,
  serialized_end=838,
)


_RESERVEINCREMENT = _descriptor.Descriptor(
  name='ReserveIncrement',
  full_name='org.xrpl.rpc.v1.ReserveIncrement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.ReserveIncrement.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=840,
  serialized_end=873,
)


_SEQUENCE = _descriptor.Descriptor(
  name='Sequence',
  full_name='org.xrpl.rpc.v1.Sequence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Sequence.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=875,
  serialized_end=900,
)


_SETFLAG = _descriptor.Descriptor(
  name='SetFlag',
  full_name='org.xrpl.rpc.v1.SetFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.SetFlag.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=926,
)


_SETTLEDELAY = _descriptor.Descriptor(
  name='SettleDelay',
  full_name='org.xrpl.rpc.v1.SettleDelay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.SettleDelay.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=928,
  serialized_end=956,
)


_SIGNERLISTID = _descriptor.Descriptor(
  name='SignerListID',
  full_name='org.xrpl.rpc.v1.SignerListID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.SignerListID.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=958,
  serialized_end=987,
)


_SIGNERQUORUM = _descriptor.Descriptor(
  name='SignerQuorum',
  full_name='org.xrpl.rpc.v1.SignerQuorum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.SignerQuorum.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=989,
  serialized_end=1018,
)


_SIGNERWEIGHT = _descriptor.Descriptor(
  name='SignerWeight',
  full_name='org.xrpl.rpc.v1.SignerWeight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.SignerWeight.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1049,
)


_SOURCETAG = _descriptor.Descriptor(
  name='SourceTag',
  full_name='org.xrpl.rpc.v1.SourceTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.SourceTag.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1051,
  serialized_end=1077,
)


_TICKSIZE = _descriptor.Descriptor(
  name='TickSize',
  full_name='org.xrpl.rpc.v1.TickSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TickSize.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1079,
  serialized_end=1104,
)


_TICKET = _descriptor.Descriptor(
  name='Ticket',
  full_name='org.xrpl.rpc.v1.Ticket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Ticket.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1106,
  serialized_end=1129,
)


_TICKETCOUNT = _descriptor.Descriptor(
  name='TicketCount',
  full_name='org.xrpl.rpc.v1.TicketCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TicketCount.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1159,
)


_TICKETSEQUENCE = _descriptor.Descriptor(
  name='TicketSequence',
  full_name='org.xrpl.rpc.v1.TicketSequence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TicketSequence.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1192,
)


_NFTOKENTAXON = _descriptor.Descriptor(
  name='NFTokenTaxon',
  full_name='org.xrpl.rpc.v1.NFTokenTaxon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.NFTokenTaxon.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1194,
  serialized_end=1223,
)


_TRANSFERFEE = _descriptor.Descriptor(
  name='TransferFee',
  full_name='org.xrpl.rpc.v1.TransferFee',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TransferFee.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1225,
  serialized_end=1253,
)


_TRANSFERRATE = _descriptor.Descriptor(
  name='TransferRate',
  full_name='org.xrpl.rpc.v1.TransferRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TransferRate.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1255,
  serialized_end=1284,
)


_BASEFEE = _descriptor.Descriptor(
  name='BaseFee',
  full_name='org.xrpl.rpc.v1.BaseFee',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.BaseFee.value', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1286,
  serialized_end=1314,
)


_BOOKNODE = _descriptor.Descriptor(
  name='BookNode',
  full_name='org.xrpl.rpc.v1.BookNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.BookNode.value', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1316,
  serialized_end=1345,
)


_DESTINATIONNODE = _descriptor.Descriptor(
  name='DestinationNode',
  full_name='org.xrpl.rpc.v1.DestinationNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.DestinationNode.value', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1347,
  serialized_end=1383,
)


_HIGHNODE = _descriptor.Descriptor(
  name='HighNode',
  full_name='org.xrpl.rpc.v1.HighNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.HighNode.value', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1385,
  serialized_end=1414,
)


_INDEXNEXT = _descriptor.Descriptor(
  name='IndexNext',
  full_name='org.xrpl.rpc.v1.IndexNext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.IndexNext.value', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1416,
  serialized_end=1446,
)


_INDEXPREVIOUS = _descriptor.Descriptor(
  name='IndexPrevious',
  full_name='org.xrpl.rpc.v1.IndexPrevious',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.IndexPrevious.value', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1448,
  serialized_end=1482,
)


_LOWNODE = _descriptor.Descriptor(
  name='LowNode',
  full_name='org.xrpl.rpc.v1.LowNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.LowNode.value', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1484,
  serialized_end=1512,
)


_NFTOKENOFFERNODE = _descriptor.Descriptor(
  name='NFTokenOfferNode',
  full_name='org.xrpl.rpc.v1.NFTokenOfferNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.NFTokenOfferNode.value', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1551,
)


_OWNERNODE = _descriptor.Descriptor(
  name='OwnerNode',
  full_name='org.xrpl.rpc.v1.OwnerNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.OwnerNode.value', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1553,
  serialized_end=1583,
)


_EMAILHASH = _descriptor.Descriptor(
  name='EmailHash',
  full_name='org.xrpl.rpc.v1.EmailHash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.EmailHash.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1585,
  serialized_end=1611,
)


_NFTOKENID = _descriptor.Descriptor(
  name='NFTokenID',
  full_name='org.xrpl.rpc.v1.NFTokenID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.NFTokenID.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1613,
  serialized_end=1639,
)


_TAKERGETSISSUER = _descriptor.Descriptor(
  name='TakerGetsIssuer',
  full_name='org.xrpl.rpc.v1.TakerGetsIssuer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TakerGetsIssuer.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1641,
  serialized_end=1673,
)


_TAKERPAYSISSUER = _descriptor.Descriptor(
  name='TakerPaysIssuer',
  full_name='org.xrpl.rpc.v1.TakerPaysIssuer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TakerPaysIssuer.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1675,
  serialized_end=1707,
)


_ACCOUNTTRANSACTIONID = _descriptor.Descriptor(
  name='AccountTransactionID',
  full_name='org.xrpl.rpc.v1.AccountTransactionID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.AccountTransactionID.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1709,
  serialized_end=1746,
)


_BOOKDIRECTORY = _descriptor.Descriptor(
  name='BookDirectory',
  full_name='org.xrpl.rpc.v1.BookDirectory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.BookDirectory.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1748,
  serialized_end=1778,
)


_CHANNEL = _descriptor.Descriptor(
  name='Channel',
  full_name='org.xrpl.rpc.v1.Channel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Channel.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1780,
  serialized_end=1804,
)


_CHECKID = _descriptor.Descriptor(
  name='CheckID',
  full_name='org.xrpl.rpc.v1.CheckID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.CheckID.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1806,
  serialized_end=1830,
)


_HASH = _descriptor.Descriptor(
  name='Hash',
  full_name='org.xrpl.rpc.v1.Hash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Hash.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1832,
  serialized_end=1853,
)


_INDEX = _descriptor.Descriptor(
  name='Index',
  full_name='org.xrpl.rpc.v1.Index',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Index.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1855,
  serialized_end=1877,
)


_INVOICEID = _descriptor.Descriptor(
  name='InvoiceID',
  full_name='org.xrpl.rpc.v1.InvoiceID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.InvoiceID.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1879,
  serialized_end=1905,
)


_NEXTPAGEMIN = _descriptor.Descriptor(
  name='NextPageMin',
  full_name='org.xrpl.rpc.v1.NextPageMin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.NextPageMin.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1907,
  serialized_end=1935,
)


_NFTOKENBUYOFFER = _descriptor.Descriptor(
  name='NFTokenBuyOffer',
  full_name='org.xrpl.rpc.v1.NFTokenBuyOffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.NFTokenBuyOffer.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1937,
  serialized_end=1969,
)


_NFTOKENSELLOFFER = _descriptor.Descriptor(
  name='NFTokenSellOffer',
  full_name='org.xrpl.rpc.v1.NFTokenSellOffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.NFTokenSellOffer.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1971,
  serialized_end=2004,
)


_PREVIOUSPAGEMIN = _descriptor.Descriptor(
  name='PreviousPageMin',
  full_name='org.xrpl.rpc.v1.PreviousPageMin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.PreviousPageMin.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2006,
  serialized_end=2038,
)


_PREVIOUSTRANSACTIONID = _descriptor.Descriptor(
  name='PreviousTransactionID',
  full_name='org.xrpl.rpc.v1.PreviousTransactionID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.PreviousTransactionID.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2040,
  serialized_end=2078,
)


_ROOTINDEX = _descriptor.Descriptor(
  name='RootIndex',
  full_name='org.xrpl.rpc.v1.RootIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.RootIndex.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2080,
  serialized_end=2106,
)


_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='org.xrpl.rpc.v1.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Condition.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2108,
  serialized_end=2134,
)


_FULFILLMENT = _descriptor.Descriptor(
  name='Fulfillment',
  full_name='org.xrpl.rpc.v1.Fulfillment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Fulfillment.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2136,
  serialized_end=2164,
)


_MEMODATA = _descriptor.Descriptor(
  name='MemoData',
  full_name='org.xrpl.rpc.v1.MemoData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.MemoData.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2166,
  serialized_end=2191,
)


_MEMOFORMAT = _descriptor.Descriptor(
  name='MemoFormat',
  full_name='org.xrpl.rpc.v1.MemoFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.MemoFormat.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2193,
  serialized_end=2220,
)


_MEMOTYPE = _descriptor.Descriptor(
  name='MemoType',
  full_name='org.xrpl.rpc.v1.MemoType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.MemoType.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2222,
  serialized_end=2247,
)


_MESSAGEKEY = _descriptor.Descriptor(
  name='MessageKey',
  full_name='org.xrpl.rpc.v1.MessageKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.MessageKey.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2249,
  serialized_end=2276,
)


_PUBLICKEY = _descriptor.Descriptor(
  name='PublicKey',
  full_name='org.xrpl.rpc.v1.PublicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.PublicKey.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2278,
  serialized_end=2304,
)


_PAYMENTCHANNELSIGNATURE = _descriptor.Descriptor(
  name='PaymentChannelSignature',
  full_name='org.xrpl.rpc.v1.PaymentChannelSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.PaymentChannelSignature.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2306,
  serialized_end=2346,
)


_SIGNINGPUBLICKEY = _descriptor.Descriptor(
  name='SigningPublicKey',
  full_name='org.xrpl.rpc.v1.SigningPublicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.SigningPublicKey.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2348,
  serialized_end=2381,
)


_TRANSACTIONSIGNATURE = _descriptor.Descriptor(
  name='TransactionSignature',
  full_name='org.xrpl.rpc.v1.TransactionSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TransactionSignature.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2383,
  serialized_end=2420,
)


_VALIDATORTODISABLE = _descriptor.Descriptor(
  name='ValidatorToDisable',
  full_name='org.xrpl.rpc.v1.ValidatorToDisable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.ValidatorToDisable.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2422,
  serialized_end=2457,
)


_VALIDATORTOREENABLE = _descriptor.Descriptor(
  name='ValidatorToReEnable',
  full_name='org.xrpl.rpc.v1.ValidatorToReEnable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.ValidatorToReEnable.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2459,
  serialized_end=2495,
)


_TAKERGETSCURRENY = _descriptor.Descriptor(
  name='TakerGetsCurreny',
  full_name='org.xrpl.rpc.v1.TakerGetsCurreny',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TakerGetsCurreny.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2497,
  serialized_end=2557,
)


_TAKERPAYSCURRENCY = _descriptor.Descriptor(
  name='TakerPaysCurrency',
  full_name='org.xrpl.rpc.v1.TakerPaysCurrency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TakerPaysCurrency.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2559,
  serialized_end=2620,
)


_AMOUNT = _descriptor.Descriptor(
  name='Amount',
  full_name='org.xrpl.rpc.v1.Amount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Amount.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2622,
  serialized_end=2678,
)


_BALANCE = _descriptor.Descriptor(
  name='Balance',
  full_name='org.xrpl.rpc.v1.Balance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Balance.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2680,
  serialized_end=2737,
)


_NFTOKENBROKERFEE = _descriptor.Descriptor(
  name='NFTokenBrokerFee',
  full_name='org.xrpl.rpc.v1.NFTokenBrokerFee',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.NFTokenBrokerFee.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2739,
  serialized_end=2805,
)


_DELIVERMIN = _descriptor.Descriptor(
  name='DeliverMin',
  full_name='org.xrpl.rpc.v1.DeliverMin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.DeliverMin.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2807,
  serialized_end=2867,
)


_DELIVEREDAMOUNT = _descriptor.Descriptor(
  name='DeliveredAmount',
  full_name='org.xrpl.rpc.v1.DeliveredAmount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.DeliveredAmount.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2869,
  serialized_end=2934,
)


_HIGHLIMIT = _descriptor.Descriptor(
  name='HighLimit',
  full_name='org.xrpl.rpc.v1.HighLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.HighLimit.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2936,
  serialized_end=2995,
)


_LIMITAMOUNT = _descriptor.Descriptor(
  name='LimitAmount',
  full_name='org.xrpl.rpc.v1.LimitAmount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.LimitAmount.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2997,
  serialized_end=3058,
)


_LOWLIMIT = _descriptor.Descriptor(
  name='LowLimit',
  full_name='org.xrpl.rpc.v1.LowLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.LowLimit.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3060,
  serialized_end=3118,
)


_SENDMAX = _descriptor.Descriptor(
  name='SendMax',
  full_name='org.xrpl.rpc.v1.SendMax',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.SendMax.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3120,
  serialized_end=3177,
)


_TAKERGETS = _descriptor.Descriptor(
  name='TakerGets',
  full_name='org.xrpl.rpc.v1.TakerGets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TakerGets.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3179,
  serialized_end=3238,
)


_TAKERPAYS = _descriptor.Descriptor(
  name='TakerPays',
  full_name='org.xrpl.rpc.v1.TakerPays',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.TakerPays.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3240,
  serialized_end=3299,
)


_ACCOUNT = _descriptor.Descriptor(
  name='Account',
  full_name='org.xrpl.rpc.v1.Account',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Account.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3301,
  serialized_end=3358,
)


_AUTHORIZE = _descriptor.Descriptor(
  name='Authorize',
  full_name='org.xrpl.rpc.v1.Authorize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Authorize.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3360,
  serialized_end=3419,
)


_DESTINATION = _descriptor.Descriptor(
  name='Destination',
  full_name='org.xrpl.rpc.v1.Destination',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Destination.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3421,
  serialized_end=3482,
)


_ISSUER = _descriptor.Descriptor(
  name='Issuer',
  full_name='org.xrpl.rpc.v1.Issuer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Issuer.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3484,
  serialized_end=3540,
)


_NFTOKENMINTER = _descriptor.Descriptor(
  name='NFTokenMinter',
  full_name='org.xrpl.rpc.v1.NFTokenMinter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.NFTokenMinter.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3542,
  serialized_end=3605,
)


_OWNER = _descriptor.Descriptor(
  name='Owner',
  full_name='org.xrpl.rpc.v1.Owner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Owner.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3607,
  serialized_end=3662,
)


_REGULARKEY = _descriptor.Descriptor(
  name='RegularKey',
  full_name='org.xrpl.rpc.v1.RegularKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.RegularKey.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3664,
  serialized_end=3724,
)


_UNAUTHORIZE = _descriptor.Descriptor(
  name='Unauthorize',
  full_name='org.xrpl.rpc.v1.Unauthorize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Unauthorize.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3726,
  serialized_end=3787,
)


_DOMAIN = _descriptor.Descriptor(
  name='Domain',
  full_name='org.xrpl.rpc.v1.Domain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Domain.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3789,
  serialized_end=3812,
)


_URI = _descriptor.Descriptor(
  name='URI',
  full_name='org.xrpl.rpc.v1.URI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.URI.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3814,
  serialized_end=3834,
)


_NFTOKEN = _descriptor.Descriptor(
  name='NFToken',
  full_name='org.xrpl.rpc.v1.NFToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nftoken_id', full_name='org.xrpl.rpc.v1.NFToken.nftoken_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='org.xrpl.rpc.v1.NFToken.uri', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3836,
  serialized_end=3928,
)


_SIGNERENTRY = _descriptor.Descriptor(
  name='SignerEntry',
  full_name='org.xrpl.rpc.v1.SignerEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.SignerEntry.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_weight', full_name='org.xrpl.rpc.v1.SignerEntry.signer_weight', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3930,
  serialized_end=4040,
)


_DISABLEDVALIDATOR = _descriptor.Descriptor(
  name='DisabledValidator',
  full_name='org.xrpl.rpc.v1.DisabledValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='org.xrpl.rpc.v1.DisabledValidator.public_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_sequence', full_name='org.xrpl.rpc.v1.DisabledValidator.ledger_sequence', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4043,
  serialized_end=4173,
)

_TAKERGETSCURRENY.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCY
_TAKERPAYSCURRENCY.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCY
_AMOUNT.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCYAMOUNT
_BALANCE.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCYAMOUNT
_NFTOKENBROKERFEE.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCYAMOUNT
_DELIVERMIN.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCYAMOUNT
_DELIVEREDAMOUNT.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCYAMOUNT
_HIGHLIMIT.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCYAMOUNT
_LIMITAMOUNT.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCYAMOUNT
_LOWLIMIT.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCYAMOUNT
_SENDMAX.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCYAMOUNT
_TAKERGETS.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCYAMOUNT
_TAKERPAYS.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCYAMOUNT
_ACCOUNT.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_AUTHORIZE.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_DESTINATION.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_ISSUER.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_NFTOKENMINTER.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_OWNER.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_REGULARKEY.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_UNAUTHORIZE.fields_by_name['value'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_NFTOKEN.fields_by_name['nftoken_id'].message_type = _NFTOKENID
_NFTOKEN.fields_by_name['uri'].message_type = _URI
_SIGNERENTRY.fields_by_name['account'].message_type = _ACCOUNT
_SIGNERENTRY.fields_by_name['signer_weight'].message_type = _SIGNERWEIGHT
_DISABLEDVALIDATOR.fields_by_name['public_key'].message_type = _PUBLICKEY
_DISABLEDVALIDATOR.fields_by_name['ledger_sequence'].message_type = _FIRSTLEDGERSEQUENCE
DESCRIPTOR.message_types_by_name['BurnedNFTokens'] = _BURNEDNFTOKENS
DESCRIPTOR.message_types_by_name['CancelAfter'] = _CANCELAFTER
DESCRIPTOR.message_types_by_name['ClearFlag'] = _CLEARFLAG
DESCRIPTOR.message_types_by_name['CloseTime'] = _CLOSETIME
DESCRIPTOR.message_types_by_name['Date'] = _DATE
DESCRIPTOR.message_types_by_name['DestinationTag'] = _DESTINATIONTAG
DESCRIPTOR.message_types_by_name['Expiration'] = _EXPIRATION
DESCRIPTOR.message_types_by_name['FinishAfter'] = _FINISHAFTER
DESCRIPTOR.message_types_by_name['Flags'] = _FLAGS
DESCRIPTOR.message_types_by_name['HighQualityIn'] = _HIGHQUALITYIN
DESCRIPTOR.message_types_by_name['HighQualityOut'] = _HIGHQUALITYOUT
DESCRIPTOR.message_types_by_name['FirstLedgerSequence'] = _FIRSTLEDGERSEQUENCE
DESCRIPTOR.message_types_by_name['LastLedgerSequence'] = _LASTLEDGERSEQUENCE
DESCRIPTOR.message_types_by_name['LowQualityIn'] = _LOWQUALITYIN
DESCRIPTOR.message_types_by_name['LowQualityOut'] = _LOWQUALITYOUT
DESCRIPTOR.message_types_by_name['MintedNFTokens'] = _MINTEDNFTOKENS
DESCRIPTOR.message_types_by_name['OfferSequence'] = _OFFERSEQUENCE
DESCRIPTOR.message_types_by_name['OwnerCount'] = _OWNERCOUNT
DESCRIPTOR.message_types_by_name['PreviousTransactionLedgerSequence'] = _PREVIOUSTRANSACTIONLEDGERSEQUENCE
DESCRIPTOR.message_types_by_name['QualityIn'] = _QUALITYIN
DESCRIPTOR.message_types_by_name['QualityOut'] = _QUALITYOUT
DESCRIPTOR.message_types_by_name['ReferenceFeeUnits'] = _REFERENCEFEEUNITS
DESCRIPTOR.message_types_by_name['ReserveBase'] = _RESERVEBASE
DESCRIPTOR.message_types_by_name['ReserveIncrement'] = _RESERVEINCREMENT
DESCRIPTOR.message_types_by_name['Sequence'] = _SEQUENCE
DESCRIPTOR.message_types_by_name['SetFlag'] = _SETFLAG
DESCRIPTOR.message_types_by_name['SettleDelay'] = _SETTLEDELAY
DESCRIPTOR.message_types_by_name['SignerListID'] = _SIGNERLISTID
DESCRIPTOR.message_types_by_name['SignerQuorum'] = _SIGNERQUORUM
DESCRIPTOR.message_types_by_name['SignerWeight'] = _SIGNERWEIGHT
DESCRIPTOR.message_types_by_name['SourceTag'] = _SOURCETAG
DESCRIPTOR.message_types_by_name['TickSize'] = _TICKSIZE
DESCRIPTOR.message_types_by_name['Ticket'] = _TICKET
DESCRIPTOR.message_types_by_name['TicketCount'] = _TICKETCOUNT
DESCRIPTOR.message_types_by_name['TicketSequence'] = _TICKETSEQUENCE
DESCRIPTOR.message_types_by_name['NFTokenTaxon'] = _NFTOKENTAXON
DESCRIPTOR.message_types_by_name['TransferFee'] = _TRANSFERFEE
DESCRIPTOR.message_types_by_name['TransferRate'] = _TRANSFERRATE
DESCRIPTOR.message_types_by_name['BaseFee'] = _BASEFEE
DESCRIPTOR.message_types_by_name['BookNode'] = _BOOKNODE
DESCRIPTOR.message_types_by_name['DestinationNode'] = _DESTINATIONNODE
DESCRIPTOR.message_types_by_name['HighNode'] = _HIGHNODE
DESCRIPTOR.message_types_by_name['IndexNext'] = _INDEXNEXT
DESCRIPTOR.message_types_by_name['IndexPrevious'] = _INDEXPREVIOUS
DESCRIPTOR.message_types_by_name['LowNode'] = _LOWNODE
DESCRIPTOR.message_types_by_name['NFTokenOfferNode'] = _NFTOKENOFFERNODE
DESCRIPTOR.message_types_by_name['OwnerNode'] = _OWNERNODE
DESCRIPTOR.message_types_by_name['EmailHash'] = _EMAILHASH
DESCRIPTOR.message_types_by_name['NFTokenID'] = _NFTOKENID
DESCRIPTOR.message_types_by_name['TakerGetsIssuer'] = _TAKERGETSISSUER
DESCRIPTOR.message_types_by_name['TakerPaysIssuer'] = _TAKERPAYSISSUER
DESCRIPTOR.message_types_by_name['AccountTransactionID'] = _ACCOUNTTRANSACTIONID
DESCRIPTOR.message_types_by_name['BookDirectory'] = _BOOKDIRECTORY
DESCRIPTOR.message_types_by_name['Channel'] = _CHANNEL
DESCRIPTOR.message_types_by_name['CheckID'] = _CHECKID
DESCRIPTOR.message_types_by_name['Hash'] = _HASH
DESCRIPTOR.message_types_by_name['Index'] = _INDEX
DESCRIPTOR.message_types_by_name['InvoiceID'] = _INVOICEID
DESCRIPTOR.message_types_by_name['NextPageMin'] = _NEXTPAGEMIN
DESCRIPTOR.message_types_by_name['NFTokenBuyOffer'] = _NFTOKENBUYOFFER
DESCRIPTOR.message_types_by_name['NFTokenSellOffer'] = _NFTOKENSELLOFFER
DESCRIPTOR.message_types_by_name['PreviousPageMin'] = _PREVIOUSPAGEMIN
DESCRIPTOR.message_types_by_name['PreviousTransactionID'] = _PREVIOUSTRANSACTIONID
DESCRIPTOR.message_types_by_name['RootIndex'] = _ROOTINDEX
DESCRIPTOR.message_types_by_name['Condition'] = _CONDITION
DESCRIPTOR.message_types_by_name['Fulfillment'] = _FULFILLMENT
DESCRIPTOR.message_types_by_name['MemoData'] = _MEMODATA
DESCRIPTOR.message_types_by_name['MemoFormat'] = _MEMOFORMAT
DESCRIPTOR.message_types_by_name['MemoType'] = _MEMOTYPE
DESCRIPTOR.message_types_by_name['MessageKey'] = _MESSAGEKEY
DESCRIPTOR.message_types_by_name['PublicKey'] = _PUBLICKEY
DESCRIPTOR.message_types_by_name['PaymentChannelSignature'] = _PAYMENTCHANNELSIGNATURE
DESCRIPTOR.message_types_by_name['SigningPublicKey'] = _SIGNINGPUBLICKEY
DESCRIPTOR.message_types_by_name['TransactionSignature'] = _TRANSACTIONSIGNATURE
DESCRIPTOR.message_types_by_name['ValidatorToDisable'] = _VALIDATORTODISABLE
DESCRIPTOR.message_types_by_name['ValidatorToReEnable'] = _VALIDATORTOREENABLE
DESCRIPTOR.message_types_by_name['TakerGetsCurreny'] = _TAKERGETSCURRENY
DESCRIPTOR.message_types_by_name['TakerPaysCurrency'] = _TAKERPAYSCURRENCY
DESCRIPTOR.message_types_by_name['Amount'] = _AMOUNT
DESCRIPTOR.message_types_by_name['Balance'] = _BALANCE
DESCRIPTOR.message_types_by_name['NFTokenBrokerFee'] = _NFTOKENBROKERFEE
DESCRIPTOR.message_types_by_name['DeliverMin'] = _DELIVERMIN
DESCRIPTOR.message_types_by_name['DeliveredAmount'] = _DELIVEREDAMOUNT
DESCRIPTOR.message_types_by_name['HighLimit'] = _HIGHLIMIT
DESCRIPTOR.message_types_by_name['LimitAmount'] = _LIMITAMOUNT
DESCRIPTOR.message_types_by_name['LowLimit'] = _LOWLIMIT
DESCRIPTOR.message_types_by_name['SendMax'] = _SENDMAX
DESCRIPTOR.message_types_by_name['TakerGets'] = _TAKERGETS
DESCRIPTOR.message_types_by_name['TakerPays'] = _TAKERPAYS
DESCRIPTOR.message_types_by_name['Account'] = _ACCOUNT
DESCRIPTOR.message_types_by_name['Authorize'] = _AUTHORIZE
DESCRIPTOR.message_types_by_name['Destination'] = _DESTINATION
DESCRIPTOR.message_types_by_name['Issuer'] = _ISSUER
DESCRIPTOR.message_types_by_name['NFTokenMinter'] = _NFTOKENMINTER
DESCRIPTOR.message_types_by_name['Owner'] = _OWNER
DESCRIPTOR.message_types_by_name['RegularKey'] = _REGULARKEY
DESCRIPTOR.message_types_by_name['Unauthorize'] = _UNAUTHORIZE
DESCRIPTOR.message_types_by_name['Domain'] = _DOMAIN
DESCRIPTOR.message_types_by_name['URI'] = _URI
DESCRIPTOR.message_types_by_name['NFToken'] = _NFTOKEN
DESCRIPTOR.message_types_by_name['SignerEntry'] = _SIGNERENTRY
DESCRIPTOR.message_types_by_name['DisabledValidator'] = _DISABLEDVALIDATOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BurnedNFTokens = _reflection.GeneratedProtocolMessageType('BurnedNFTokens', (_message.Message,), {
  'DESCRIPTOR' : _BURNEDNFTOKENS,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.BurnedNFTokens)
  })
_sym_db.RegisterMessage(BurnedNFTokens)

CancelAfter = _reflection.GeneratedProtocolMessageType('CancelAfter', (_message.Message,), {
  'DESCRIPTOR' : _CANCELAFTER,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.CancelAfter)
  })
_sym_db.RegisterMessage(CancelAfter)

ClearFlag = _reflection.GeneratedProtocolMessageType('ClearFlag', (_message.Message,), {
  'DESCRIPTOR' : _CLEARFLAG,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.ClearFlag)
  })
_sym_db.RegisterMessage(ClearFlag)

CloseTime = _reflection.GeneratedProtocolMessageType('CloseTime', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETIME,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.CloseTime)
  })
_sym_db.RegisterMessage(CloseTime)

Date = _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
  'DESCRIPTOR' : _DATE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Date)
  })
_sym_db.RegisterMessage(Date)

DestinationTag = _reflection.GeneratedProtocolMessageType('DestinationTag', (_message.Message,), {
  'DESCRIPTOR' : _DESTINATIONTAG,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.DestinationTag)
  })
_sym_db.RegisterMessage(DestinationTag)

Expiration = _reflection.GeneratedProtocolMessageType('Expiration', (_message.Message,), {
  'DESCRIPTOR' : _EXPIRATION,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Expiration)
  })
_sym_db.RegisterMessage(Expiration)

FinishAfter = _reflection.GeneratedProtocolMessageType('FinishAfter', (_message.Message,), {
  'DESCRIPTOR' : _FINISHAFTER,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.FinishAfter)
  })
_sym_db.RegisterMessage(FinishAfter)

Flags = _reflection.GeneratedProtocolMessageType('Flags', (_message.Message,), {
  'DESCRIPTOR' : _FLAGS,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Flags)
  })
_sym_db.RegisterMessage(Flags)

HighQualityIn = _reflection.GeneratedProtocolMessageType('HighQualityIn', (_message.Message,), {
  'DESCRIPTOR' : _HIGHQUALITYIN,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.HighQualityIn)
  })
_sym_db.RegisterMessage(HighQualityIn)

HighQualityOut = _reflection.GeneratedProtocolMessageType('HighQualityOut', (_message.Message,), {
  'DESCRIPTOR' : _HIGHQUALITYOUT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.HighQualityOut)
  })
_sym_db.RegisterMessage(HighQualityOut)

FirstLedgerSequence = _reflection.GeneratedProtocolMessageType('FirstLedgerSequence', (_message.Message,), {
  'DESCRIPTOR' : _FIRSTLEDGERSEQUENCE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.FirstLedgerSequence)
  })
_sym_db.RegisterMessage(FirstLedgerSequence)

LastLedgerSequence = _reflection.GeneratedProtocolMessageType('LastLedgerSequence', (_message.Message,), {
  'DESCRIPTOR' : _LASTLEDGERSEQUENCE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LastLedgerSequence)
  })
_sym_db.RegisterMessage(LastLedgerSequence)

LowQualityIn = _reflection.GeneratedProtocolMessageType('LowQualityIn', (_message.Message,), {
  'DESCRIPTOR' : _LOWQUALITYIN,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LowQualityIn)
  })
_sym_db.RegisterMessage(LowQualityIn)

LowQualityOut = _reflection.GeneratedProtocolMessageType('LowQualityOut', (_message.Message,), {
  'DESCRIPTOR' : _LOWQUALITYOUT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LowQualityOut)
  })
_sym_db.RegisterMessage(LowQualityOut)

MintedNFTokens = _reflection.GeneratedProtocolMessageType('MintedNFTokens', (_message.Message,), {
  'DESCRIPTOR' : _MINTEDNFTOKENS,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.MintedNFTokens)
  })
_sym_db.RegisterMessage(MintedNFTokens)

OfferSequence = _reflection.GeneratedProtocolMessageType('OfferSequence', (_message.Message,), {
  'DESCRIPTOR' : _OFFERSEQUENCE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.OfferSequence)
  })
_sym_db.RegisterMessage(OfferSequence)

OwnerCount = _reflection.GeneratedProtocolMessageType('OwnerCount', (_message.Message,), {
  'DESCRIPTOR' : _OWNERCOUNT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.OwnerCount)
  })
_sym_db.RegisterMessage(OwnerCount)

PreviousTransactionLedgerSequence = _reflection.GeneratedProtocolMessageType('PreviousTransactionLedgerSequence', (_message.Message,), {
  'DESCRIPTOR' : _PREVIOUSTRANSACTIONLEDGERSEQUENCE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.PreviousTransactionLedgerSequence)
  })
_sym_db.RegisterMessage(PreviousTransactionLedgerSequence)

QualityIn = _reflection.GeneratedProtocolMessageType('QualityIn', (_message.Message,), {
  'DESCRIPTOR' : _QUALITYIN,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.QualityIn)
  })
_sym_db.RegisterMessage(QualityIn)

QualityOut = _reflection.GeneratedProtocolMessageType('QualityOut', (_message.Message,), {
  'DESCRIPTOR' : _QUALITYOUT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.QualityOut)
  })
_sym_db.RegisterMessage(QualityOut)

ReferenceFeeUnits = _reflection.GeneratedProtocolMessageType('ReferenceFeeUnits', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCEFEEUNITS,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.ReferenceFeeUnits)
  })
_sym_db.RegisterMessage(ReferenceFeeUnits)

ReserveBase = _reflection.GeneratedProtocolMessageType('ReserveBase', (_message.Message,), {
  'DESCRIPTOR' : _RESERVEBASE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.ReserveBase)
  })
_sym_db.RegisterMessage(ReserveBase)

ReserveIncrement = _reflection.GeneratedProtocolMessageType('ReserveIncrement', (_message.Message,), {
  'DESCRIPTOR' : _RESERVEINCREMENT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.ReserveIncrement)
  })
_sym_db.RegisterMessage(ReserveIncrement)

Sequence = _reflection.GeneratedProtocolMessageType('Sequence', (_message.Message,), {
  'DESCRIPTOR' : _SEQUENCE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Sequence)
  })
_sym_db.RegisterMessage(Sequence)

SetFlag = _reflection.GeneratedProtocolMessageType('SetFlag', (_message.Message,), {
  'DESCRIPTOR' : _SETFLAG,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SetFlag)
  })
_sym_db.RegisterMessage(SetFlag)

SettleDelay = _reflection.GeneratedProtocolMessageType('SettleDelay', (_message.Message,), {
  'DESCRIPTOR' : _SETTLEDELAY,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SettleDelay)
  })
_sym_db.RegisterMessage(SettleDelay)

SignerListID = _reflection.GeneratedProtocolMessageType('SignerListID', (_message.Message,), {
  'DESCRIPTOR' : _SIGNERLISTID,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SignerListID)
  })
_sym_db.RegisterMessage(SignerListID)

SignerQuorum = _reflection.GeneratedProtocolMessageType('SignerQuorum', (_message.Message,), {
  'DESCRIPTOR' : _SIGNERQUORUM,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SignerQuorum)
  })
_sym_db.RegisterMessage(SignerQuorum)

SignerWeight = _reflection.GeneratedProtocolMessageType('SignerWeight', (_message.Message,), {
  'DESCRIPTOR' : _SIGNERWEIGHT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SignerWeight)
  })
_sym_db.RegisterMessage(SignerWeight)

SourceTag = _reflection.GeneratedProtocolMessageType('SourceTag', (_message.Message,), {
  'DESCRIPTOR' : _SOURCETAG,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SourceTag)
  })
_sym_db.RegisterMessage(SourceTag)

TickSize = _reflection.GeneratedProtocolMessageType('TickSize', (_message.Message,), {
  'DESCRIPTOR' : _TICKSIZE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TickSize)
  })
_sym_db.RegisterMessage(TickSize)

Ticket = _reflection.GeneratedProtocolMessageType('Ticket', (_message.Message,), {
  'DESCRIPTOR' : _TICKET,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Ticket)
  })
_sym_db.RegisterMessage(Ticket)

TicketCount = _reflection.GeneratedProtocolMessageType('TicketCount', (_message.Message,), {
  'DESCRIPTOR' : _TICKETCOUNT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TicketCount)
  })
_sym_db.RegisterMessage(TicketCount)

TicketSequence = _reflection.GeneratedProtocolMessageType('TicketSequence', (_message.Message,), {
  'DESCRIPTOR' : _TICKETSEQUENCE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TicketSequence)
  })
_sym_db.RegisterMessage(TicketSequence)

NFTokenTaxon = _reflection.GeneratedProtocolMessageType('NFTokenTaxon', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENTAXON,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenTaxon)
  })
_sym_db.RegisterMessage(NFTokenTaxon)

TransferFee = _reflection.GeneratedProtocolMessageType('TransferFee', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERFEE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TransferFee)
  })
_sym_db.RegisterMessage(TransferFee)

TransferRate = _reflection.GeneratedProtocolMessageType('TransferRate', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERRATE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TransferRate)
  })
_sym_db.RegisterMessage(TransferRate)

BaseFee = _reflection.GeneratedProtocolMessageType('BaseFee', (_message.Message,), {
  'DESCRIPTOR' : _BASEFEE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.BaseFee)
  })
_sym_db.RegisterMessage(BaseFee)

BookNode = _reflection.GeneratedProtocolMessageType('BookNode', (_message.Message,), {
  'DESCRIPTOR' : _BOOKNODE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.BookNode)
  })
_sym_db.RegisterMessage(BookNode)

DestinationNode = _reflection.GeneratedProtocolMessageType('DestinationNode', (_message.Message,), {
  'DESCRIPTOR' : _DESTINATIONNODE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.DestinationNode)
  })
_sym_db.RegisterMessage(DestinationNode)

HighNode = _reflection.GeneratedProtocolMessageType('HighNode', (_message.Message,), {
  'DESCRIPTOR' : _HIGHNODE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.HighNode)
  })
_sym_db.RegisterMessage(HighNode)

IndexNext = _reflection.GeneratedProtocolMessageType('IndexNext', (_message.Message,), {
  'DESCRIPTOR' : _INDEXNEXT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.IndexNext)
  })
_sym_db.RegisterMessage(IndexNext)

IndexPrevious = _reflection.GeneratedProtocolMessageType('IndexPrevious', (_message.Message,), {
  'DESCRIPTOR' : _INDEXPREVIOUS,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.IndexPrevious)
  })
_sym_db.RegisterMessage(IndexPrevious)

LowNode = _reflection.GeneratedProtocolMessageType('LowNode', (_message.Message,), {
  'DESCRIPTOR' : _LOWNODE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LowNode)
  })
_sym_db.RegisterMessage(LowNode)

NFTokenOfferNode = _reflection.GeneratedProtocolMessageType('NFTokenOfferNode', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENOFFERNODE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenOfferNode)
  })
_sym_db.RegisterMessage(NFTokenOfferNode)

OwnerNode = _reflection.GeneratedProtocolMessageType('OwnerNode', (_message.Message,), {
  'DESCRIPTOR' : _OWNERNODE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.OwnerNode)
  })
_sym_db.RegisterMessage(OwnerNode)

EmailHash = _reflection.GeneratedProtocolMessageType('EmailHash', (_message.Message,), {
  'DESCRIPTOR' : _EMAILHASH,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.EmailHash)
  })
_sym_db.RegisterMessage(EmailHash)

NFTokenID = _reflection.GeneratedProtocolMessageType('NFTokenID', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENID,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenID)
  })
_sym_db.RegisterMessage(NFTokenID)

TakerGetsIssuer = _reflection.GeneratedProtocolMessageType('TakerGetsIssuer', (_message.Message,), {
  'DESCRIPTOR' : _TAKERGETSISSUER,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TakerGetsIssuer)
  })
_sym_db.RegisterMessage(TakerGetsIssuer)

TakerPaysIssuer = _reflection.GeneratedProtocolMessageType('TakerPaysIssuer', (_message.Message,), {
  'DESCRIPTOR' : _TAKERPAYSISSUER,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TakerPaysIssuer)
  })
_sym_db.RegisterMessage(TakerPaysIssuer)

AccountTransactionID = _reflection.GeneratedProtocolMessageType('AccountTransactionID', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTTRANSACTIONID,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.AccountTransactionID)
  })
_sym_db.RegisterMessage(AccountTransactionID)

BookDirectory = _reflection.GeneratedProtocolMessageType('BookDirectory', (_message.Message,), {
  'DESCRIPTOR' : _BOOKDIRECTORY,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.BookDirectory)
  })
_sym_db.RegisterMessage(BookDirectory)

Channel = _reflection.GeneratedProtocolMessageType('Channel', (_message.Message,), {
  'DESCRIPTOR' : _CHANNEL,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Channel)
  })
_sym_db.RegisterMessage(Channel)

CheckID = _reflection.GeneratedProtocolMessageType('CheckID', (_message.Message,), {
  'DESCRIPTOR' : _CHECKID,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.CheckID)
  })
_sym_db.RegisterMessage(CheckID)

Hash = _reflection.GeneratedProtocolMessageType('Hash', (_message.Message,), {
  'DESCRIPTOR' : _HASH,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Hash)
  })
_sym_db.RegisterMessage(Hash)

Index = _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), {
  'DESCRIPTOR' : _INDEX,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Index)
  })
_sym_db.RegisterMessage(Index)

InvoiceID = _reflection.GeneratedProtocolMessageType('InvoiceID', (_message.Message,), {
  'DESCRIPTOR' : _INVOICEID,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.InvoiceID)
  })
_sym_db.RegisterMessage(InvoiceID)

NextPageMin = _reflection.GeneratedProtocolMessageType('NextPageMin', (_message.Message,), {
  'DESCRIPTOR' : _NEXTPAGEMIN,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NextPageMin)
  })
_sym_db.RegisterMessage(NextPageMin)

NFTokenBuyOffer = _reflection.GeneratedProtocolMessageType('NFTokenBuyOffer', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENBUYOFFER,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenBuyOffer)
  })
_sym_db.RegisterMessage(NFTokenBuyOffer)

NFTokenSellOffer = _reflection.GeneratedProtocolMessageType('NFTokenSellOffer', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENSELLOFFER,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenSellOffer)
  })
_sym_db.RegisterMessage(NFTokenSellOffer)

PreviousPageMin = _reflection.GeneratedProtocolMessageType('PreviousPageMin', (_message.Message,), {
  'DESCRIPTOR' : _PREVIOUSPAGEMIN,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.PreviousPageMin)
  })
_sym_db.RegisterMessage(PreviousPageMin)

PreviousTransactionID = _reflection.GeneratedProtocolMessageType('PreviousTransactionID', (_message.Message,), {
  'DESCRIPTOR' : _PREVIOUSTRANSACTIONID,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.PreviousTransactionID)
  })
_sym_db.RegisterMessage(PreviousTransactionID)

RootIndex = _reflection.GeneratedProtocolMessageType('RootIndex', (_message.Message,), {
  'DESCRIPTOR' : _ROOTINDEX,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.RootIndex)
  })
_sym_db.RegisterMessage(RootIndex)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Condition)
  })
_sym_db.RegisterMessage(Condition)

Fulfillment = _reflection.GeneratedProtocolMessageType('Fulfillment', (_message.Message,), {
  'DESCRIPTOR' : _FULFILLMENT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Fulfillment)
  })
_sym_db.RegisterMessage(Fulfillment)

MemoData = _reflection.GeneratedProtocolMessageType('MemoData', (_message.Message,), {
  'DESCRIPTOR' : _MEMODATA,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.MemoData)
  })
_sym_db.RegisterMessage(MemoData)

MemoFormat = _reflection.GeneratedProtocolMessageType('MemoFormat', (_message.Message,), {
  'DESCRIPTOR' : _MEMOFORMAT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.MemoFormat)
  })
_sym_db.RegisterMessage(MemoFormat)

MemoType = _reflection.GeneratedProtocolMessageType('MemoType', (_message.Message,), {
  'DESCRIPTOR' : _MEMOTYPE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.MemoType)
  })
_sym_db.RegisterMessage(MemoType)

MessageKey = _reflection.GeneratedProtocolMessageType('MessageKey', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEKEY,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.MessageKey)
  })
_sym_db.RegisterMessage(MessageKey)

PublicKey = _reflection.GeneratedProtocolMessageType('PublicKey', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICKEY,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.PublicKey)
  })
_sym_db.RegisterMessage(PublicKey)

PaymentChannelSignature = _reflection.GeneratedProtocolMessageType('PaymentChannelSignature', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTCHANNELSIGNATURE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.PaymentChannelSignature)
  })
_sym_db.RegisterMessage(PaymentChannelSignature)

SigningPublicKey = _reflection.GeneratedProtocolMessageType('SigningPublicKey', (_message.Message,), {
  'DESCRIPTOR' : _SIGNINGPUBLICKEY,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SigningPublicKey)
  })
_sym_db.RegisterMessage(SigningPublicKey)

TransactionSignature = _reflection.GeneratedProtocolMessageType('TransactionSignature', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONSIGNATURE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TransactionSignature)
  })
_sym_db.RegisterMessage(TransactionSignature)

ValidatorToDisable = _reflection.GeneratedProtocolMessageType('ValidatorToDisable', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORTODISABLE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.ValidatorToDisable)
  })
_sym_db.RegisterMessage(ValidatorToDisable)

ValidatorToReEnable = _reflection.GeneratedProtocolMessageType('ValidatorToReEnable', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORTOREENABLE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.ValidatorToReEnable)
  })
_sym_db.RegisterMessage(ValidatorToReEnable)

TakerGetsCurreny = _reflection.GeneratedProtocolMessageType('TakerGetsCurreny', (_message.Message,), {
  'DESCRIPTOR' : _TAKERGETSCURRENY,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TakerGetsCurreny)
  })
_sym_db.RegisterMessage(TakerGetsCurreny)

TakerPaysCurrency = _reflection.GeneratedProtocolMessageType('TakerPaysCurrency', (_message.Message,), {
  'DESCRIPTOR' : _TAKERPAYSCURRENCY,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TakerPaysCurrency)
  })
_sym_db.RegisterMessage(TakerPaysCurrency)

Amount = _reflection.GeneratedProtocolMessageType('Amount', (_message.Message,), {
  'DESCRIPTOR' : _AMOUNT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Amount)
  })
_sym_db.RegisterMessage(Amount)

Balance = _reflection.GeneratedProtocolMessageType('Balance', (_message.Message,), {
  'DESCRIPTOR' : _BALANCE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Balance)
  })
_sym_db.RegisterMessage(Balance)

NFTokenBrokerFee = _reflection.GeneratedProtocolMessageType('NFTokenBrokerFee', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENBROKERFEE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenBrokerFee)
  })
_sym_db.RegisterMessage(NFTokenBrokerFee)

DeliverMin = _reflection.GeneratedProtocolMessageType('DeliverMin', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERMIN,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.DeliverMin)
  })
_sym_db.RegisterMessage(DeliverMin)

DeliveredAmount = _reflection.GeneratedProtocolMessageType('DeliveredAmount', (_message.Message,), {
  'DESCRIPTOR' : _DELIVEREDAMOUNT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.DeliveredAmount)
  })
_sym_db.RegisterMessage(DeliveredAmount)

HighLimit = _reflection.GeneratedProtocolMessageType('HighLimit', (_message.Message,), {
  'DESCRIPTOR' : _HIGHLIMIT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.HighLimit)
  })
_sym_db.RegisterMessage(HighLimit)

LimitAmount = _reflection.GeneratedProtocolMessageType('LimitAmount', (_message.Message,), {
  'DESCRIPTOR' : _LIMITAMOUNT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LimitAmount)
  })
_sym_db.RegisterMessage(LimitAmount)

LowLimit = _reflection.GeneratedProtocolMessageType('LowLimit', (_message.Message,), {
  'DESCRIPTOR' : _LOWLIMIT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LowLimit)
  })
_sym_db.RegisterMessage(LowLimit)

SendMax = _reflection.GeneratedProtocolMessageType('SendMax', (_message.Message,), {
  'DESCRIPTOR' : _SENDMAX,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SendMax)
  })
_sym_db.RegisterMessage(SendMax)

TakerGets = _reflection.GeneratedProtocolMessageType('TakerGets', (_message.Message,), {
  'DESCRIPTOR' : _TAKERGETS,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TakerGets)
  })
_sym_db.RegisterMessage(TakerGets)

TakerPays = _reflection.GeneratedProtocolMessageType('TakerPays', (_message.Message,), {
  'DESCRIPTOR' : _TAKERPAYS,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TakerPays)
  })
_sym_db.RegisterMessage(TakerPays)

Account = _reflection.GeneratedProtocolMessageType('Account', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNT,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Account)
  })
_sym_db.RegisterMessage(Account)

Authorize = _reflection.GeneratedProtocolMessageType('Authorize', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Authorize)
  })
_sym_db.RegisterMessage(Authorize)

Destination = _reflection.GeneratedProtocolMessageType('Destination', (_message.Message,), {
  'DESCRIPTOR' : _DESTINATION,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Destination)
  })
_sym_db.RegisterMessage(Destination)

Issuer = _reflection.GeneratedProtocolMessageType('Issuer', (_message.Message,), {
  'DESCRIPTOR' : _ISSUER,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Issuer)
  })
_sym_db.RegisterMessage(Issuer)

NFTokenMinter = _reflection.GeneratedProtocolMessageType('NFTokenMinter', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENMINTER,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenMinter)
  })
_sym_db.RegisterMessage(NFTokenMinter)

Owner = _reflection.GeneratedProtocolMessageType('Owner', (_message.Message,), {
  'DESCRIPTOR' : _OWNER,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Owner)
  })
_sym_db.RegisterMessage(Owner)

RegularKey = _reflection.GeneratedProtocolMessageType('RegularKey', (_message.Message,), {
  'DESCRIPTOR' : _REGULARKEY,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.RegularKey)
  })
_sym_db.RegisterMessage(RegularKey)

Unauthorize = _reflection.GeneratedProtocolMessageType('Unauthorize', (_message.Message,), {
  'DESCRIPTOR' : _UNAUTHORIZE,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Unauthorize)
  })
_sym_db.RegisterMessage(Unauthorize)

Domain = _reflection.GeneratedProtocolMessageType('Domain', (_message.Message,), {
  'DESCRIPTOR' : _DOMAIN,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Domain)
  })
_sym_db.RegisterMessage(Domain)

URI = _reflection.GeneratedProtocolMessageType('URI', (_message.Message,), {
  'DESCRIPTOR' : _URI,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.URI)
  })
_sym_db.RegisterMessage(URI)

NFToken = _reflection.GeneratedProtocolMessageType('NFToken', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKEN,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFToken)
  })
_sym_db.RegisterMessage(NFToken)

SignerEntry = _reflection.GeneratedProtocolMessageType('SignerEntry', (_message.Message,), {
  'DESCRIPTOR' : _SIGNERENTRY,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SignerEntry)
  })
_sym_db.RegisterMessage(SignerEntry)

DisabledValidator = _reflection.GeneratedProtocolMessageType('DisabledValidator', (_message.Message,), {
  'DESCRIPTOR' : _DISABLEDVALIDATOR,
  '__module__' : 'org.xrpl.rpc.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.DisabledValidator)
  })
_sym_db.RegisterMessage(DisabledValidator)


DESCRIPTOR._options = None
_BASEFEE.fields_by_name['value']._options = None
_BOOKNODE.fields_by_name['value']._options = None
_DESTINATIONNODE.fields_by_name['value']._options = None
_HIGHNODE.fields_by_name['value']._options = None
_INDEXNEXT.fields_by_name['value']._options = None
_INDEXPREVIOUS.fields_by_name['value']._options = None
_LOWNODE.fields_by_name['value']._options = None
_NFTOKENOFFERNODE.fields_by_name['value']._options = None
_OWNERNODE.fields_by_name['value']._options = None
# @@protoc_insertion_point(module_scope)
